@@ -1,5 +1,7 @@
 """Helper functions."""
 
 from .add_logical_name import add_logical_name
+from .merge_all_of import merge_all_of
+from .prepare_spec import prepare_spec
 from .resolve_ref import resolve_ref
 from .testing_guard import testing_guard
